@@ -19,6 +19,7 @@ from fosslight_util.write_excel import remove_empty_sheet
 
 PACKAGE = {
     'requirements.txt': 'pypi',
+    'setup.py': 'pypi',
     'package.json': 'npm',
     'pom.xml': 'maven',
     'build.gradle': 'gradle',
@@ -265,7 +266,17 @@ def make_resources_and_attributions(sheet_items, scanner, resources, fc_list):
                 resources = make_resources(path, resources)
                 attribution = Attribution(scanner, license, exclude, copyright, oss_name, oss_version, url)
             elif scanner == constant.FL_DEPENDENCY:
-                packageType = PACKAGE[path]
+                try:
+                    packageType = PACKAGE[path]
+                except Exception:
+                    packageType = ''
+                    if path == '':
+                        try_package_type = oss_name.split(':')[0]
+                    else:
+                        try_package_type = path.split(',')[0]
+                    if try_package_type in PACKAGE.items():
+                        packageType = try_package_type
+
                 if (os.path.join(os.sep, path) + os.sep) not in fc_list:
                     fc_list.append(os.path.join(os.sep, path) + os.sep)
                     ab_list.append(os.path.join(os.sep, path, packageType) + os.sep)
